@@ -23,7 +23,7 @@ from aliyunsdkros.endpoint import endpoint_data
 class InquiryStackRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'ROS', '2015-09-01', 'InquiryStack','ROS')
+		RoaRequest.__init__(self, 'ROS', '2015-09-01', 'InquiryStack','ros')
 		self.set_uri_pattern('/stacks/inquiry')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
