@@ -23,7 +23,7 @@ from aliyunsdkros.endpoint import endpoint_data
 class ValidateTemplateRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'ROS', '2015-09-01', 'ValidateTemplate','ROS')
+		RoaRequest.__init__(self, 'ROS', '2015-09-01', 'ValidateTemplate','ros')
 		self.set_uri_pattern('/validate')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
