@@ -73,10 +73,10 @@ class CreateChangeSetRequest(RpcRequest):
 	def set_TemplateId(self,TemplateId):
 		self.add_query_param('TemplateId',TemplateId)
 
-	def get_Parameterss(self):
+	def get_Parameters(self):
 		return self.get_query_params().get('Parameters')
 
-	def set_Parameterss(self, Parameterss):
+	def set_Parameters(self, Parameterss):
 		for depth1 in range(len(Parameterss)):
 			if Parameterss[depth1].get('ParameterValue') is not None:
 				self.add_query_param('Parameters.' + str(depth1 + 1) + '.ParameterValue', Parameterss[depth1].get('ParameterValue'))
@@ -113,18 +113,18 @@ class CreateChangeSetRequest(RpcRequest):
 	def set_TemplateURL(self,TemplateURL):
 		self.add_query_param('TemplateURL',TemplateURL)
 
-	def get_NotificationURLss(self):
+	def get_NotificationURLs(self):
 		return self.get_query_params().get('NotificationURLs')
 
-	def set_NotificationURLss(self, NotificationURLss):
+	def set_NotificationURLs(self, NotificationURLss):
 		for depth1 in range(len(NotificationURLss)):
 			if NotificationURLss[depth1] is not None:
 				self.add_query_param('NotificationURLs.' + str(depth1 + 1) , NotificationURLss[depth1])
 
-	def get_ResourcesToImports(self):
+	def get_ResourcesToImport(self):
 		return self.get_query_params().get('ResourcesToImport')
 
-	def set_ResourcesToImports(self, ResourcesToImports):
+	def set_ResourcesToImport(self, ResourcesToImports):
 		for depth1 in range(len(ResourcesToImports)):
 			if ResourcesToImports[depth1].get('ResourceIdentifier') is not None:
 				self.add_query_param('ResourcesToImport.' + str(depth1 + 1) + '.ResourceIdentifier', ResourcesToImports[depth1].get('ResourceIdentifier'))
