@@ -61,10 +61,20 @@ class UpdateStackRequest(RpcRequest):
 	def set_TemplateId(self,TemplateId):
 		self.add_query_param('TemplateId',TemplateId)
 
-	def get_Parameterss(self):
+	def get_Tags(self):
+		return self.get_query_params().get('Tags')
+
+	def set_Tags(self, Tagss):
+		for depth1 in range(len(Tagss)):
+			if Tagss[depth1].get('Value') is not None:
+				self.add_query_param('Tags.' + str(depth1 + 1) + '.Value', Tagss[depth1].get('Value'))
+			if Tagss[depth1].get('Key') is not None:
+				self.add_query_param('Tags.' + str(depth1 + 1) + '.Key', Tagss[depth1].get('Key'))
+
+	def get_Parameters(self):
 		return self.get_query_params().get('Parameters')
 
-	def set_Parameterss(self, Parameterss):
+	def set_Parameters(self, Parameterss):
 		for depth1 in range(len(Parameterss)):
 			if Parameterss[depth1].get('ParameterValue') is not None:
 				self.add_query_param('Parameters.' + str(depth1 + 1) + '.ParameterValue', Parameterss[depth1].get('ParameterValue'))
